<!--
SPDX-FileCopyrightText: 2020 Jeff Epler, written for Adafruit Industries

SPDX-License-Identifier: MIT
-->

These examples are adapted from [Getting started with MicroPython on the Raspberry Pi Pico](https://www.adafruit.com/product/4898).  You can also get an [electonic copy](https://hackspace.raspberrypi.org/books/micropython-pico/).  PIO is covered in Appendix C.
